Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5953)

Unified Diff: chrome/browser/installable/installable_logging.cc

Issue 2178833002: Add new app banner metrics using InstallableStatusCode. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@banner-integrate-checker-no-refptr
Patch Set: Fix histogram name Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/installable/installable_logging.h ('k') | chrome/browser/installable/installable_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/installable/installable_logging.cc
diff --git a/chrome/browser/installable/installable_logging.cc b/chrome/browser/installable/installable_logging.cc
index 77ec9916c1dfdb4a2a0561277b810c820466d38c..8e54ce0a5918f67360e23ad28c38576f9114f828 100644
--- a/chrome/browser/installable/installable_logging.cc
+++ b/chrome/browser/installable/installable_logging.cc
@@ -17,7 +17,7 @@ const std::string& GetMessagePrefix() {
return message_prefix;
}
// Error message strings corresponding to the InstallableErrorCode enum.
static const char kRendererExitingMessage[] =
"the page is in the process of being closed";
static const char kRendererCancelledMessage[] =
@@ -63,7 +63,7 @@ static const char kIdsDoNotMatchMessage[] =
} // namespace
void LogErrorToConsole(content::WebContents* web_contents,
- InstallableErrorCode code,
+ InstallableStatusCode code,
const std::string& param) {
if (!web_contents)
return;
@@ -72,6 +72,15 @@ void LogErrorToConsole(content::WebContents* web_contents,
const char* pattern = nullptr;
switch (code) {
case NO_ERROR_DETECTED:
+ // These codes are solely used for UMA reporting.
+ case ALREADY_INSTALLED:
+ case INSUFFICIENT_ENGAGEMENT:
+ case PACKAGE_NAME_OR_START_URL_EMPTY:
+ case PREVIOUSLY_BLOCKED:
+ case PREVIOUSLY_IGNORED:
+ case SHOWING_NATIVE_APP_BANNER:
+ case SHOWING_WEB_APP_BANNER:
+ case FAILED_TO_CREATE_BANNER:
case MAX_ERROR_CODE:
return;
case RENDERER_EXITING:
@@ -17,7 +17,7 @@ const std::string& GetMessagePrefix() {
return message_prefix;
}
-// Error message strings corresponding to the InstallableErrorCode enum.
+// Error message strings corresponding to the InstallableStatusCode enum.
static const char kRendererExitingMessage[] =
"the page is in the process of being closed";
« no previous file with comments | « chrome/browser/installable/installable_logging.h ('k') | chrome/browser/installable/installable_manager.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698